@@ -20,7 +20,7 @@ quiet_load_all_CRAN <- function(...) {
 }
 
 # load packages
-quiet_load_all_CRAN("ggplot2", "cowplot", "Seurat", "magrittr")
+quiet_load_all_CRAN("ggplot2", "cowplot", "Seurat", "dplyr")
 
 ## ----setup--------------------------------------------------------------------
 suppressPackageStartupMessages(library(APackOfTheClones))
@@ -28,7 +28,6 @@ suppressPackageStartupMessages(library(APackOfTheClones))
 pbmc <- get(data("combined_pbmc"))
 
 ## ----load_data, eval = TRUE, echo = FALSE, include = FALSE--------------------
-# TODO use a nicer looking dataset
 pbmc <- get(data("combined_pbmc"))
 
 ## ----setup_seurat, echo = TRUE, eval = FALSE----------------------------------
@@ -81,11 +80,12 @@ pbmc <- RunAPOTC(
 #  clonecall = NULL,
 #  ...,
 #  extra_filter = NULL,
+#  alt_ident = NULL
 
 ## ----apotcplot, echo = TRUE---------------------------------------------------
 # Here, plots for samples 17 - 20 as seen in the previous vignette are made, where
 # `orig.ident` is a custom column in the example data with levels corresponding to sample ids:
-# ("P17B" "P17L" "P18B" "P18L" "P19B" "P19L" "P20B" "P20L"). 
+# ("P17B" "P17L" "P18B" "P18L" "P19B" "P19L" "P20B" "P20L").
 
 pbmc <- RunAPOTC(
   pbmc, run_id = "P17", orig.ident = c("P17B", "P17L"), verbose = FALSE
